@@ -989,6 +989,7 @@ class FileFormatType(IntEnum):
     PPTM = 41,
     PPTX = 26,
     SPREADSHEET_ML = 15,
+    SQL_SCRIPT = 514,
     SVG = 28,
     SXC = 60,
     TAB_DELIMITED = 11,
@@ -1411,6 +1412,7 @@ class LoadDataFilterOptions(IntEnum):
     OLE_OBJECT = 268435456,
     PICTURE = 134217728,
     PIVOT_TABLE = 8192,
+    REVISION = 536870912,
     SETTINGS = 1114112,
     SHAPE = 402653696,
     SHEET_DATA = 403701759,
@@ -1438,6 +1440,7 @@ class LoadFormat(IntEnum):
     UNKNOWN = 255,
     XLSB = 16,
     XLSX = 6,
+    XML = 51,
 class LookAtType(IntEnum):
     CONTAINS = 0,
     END_WITH = 2,
@@ -2340,6 +2343,7 @@ class SaveFormat(IntEnum):
     PNG = 262,
     PPTX = 61,
     SPREADSHEET_ML = 15,
+    SQL_SCRIPT = 514,
     SVG = 28,
     SXC = 60,
     TAB_DELIMITED = 11,
@@ -2352,6 +2356,7 @@ class SaveFormat(IntEnum):
     XLSX = 6,
     XLTM = 9,
     XLTX = 8,
+    XML = 51,
     XPS = 20,
 class SelectionType(IntEnum):
     EXTEND = 2,
@@ -2522,6 +2527,10 @@ class SqlDataType(IntEnum):
     SQL_W_CHAR = -8,
     SQL_W_LONG_VARCHAR = -10,
     SQL_W_VARCHAR = -9,
+class SqlScriptOperatorType(IntEnum):
+    DELETE = 2,
+    INSERT = 0,
+    UPDATE = 1,
 class StyleModifyFlag(IntEnum):
     ALIGNMENT_SETTINGS = 38,
     ALL = 0,
@@ -3012,6 +3021,8 @@ from com.aspose.cells import SignatureLine
 from com.aspose.cells import SmartTagOptions
 from com.aspose.cells import SmartTagPropertyCollection
 from com.aspose.cells import SpreadsheetML2003SaveOptions
+from com.aspose.cells import SqlScriptColumnTypeMap
+from com.aspose.cells import SqlScriptSaveOptions
 from com.aspose.cells import Style
 from com.aspose.cells import StyleFlag
 from com.aspose.cells import SvgSaveOptions
@@ -3036,6 +3047,8 @@ from com.aspose.cells import WriteProtection
 from com.aspose.cells import XlsbSaveOptions
 from com.aspose.cells import XlsSaveOptions
 from com.aspose.cells import XmlColumnProperty
+from com.aspose.cells import XmlLoadOptions
+from com.aspose.cells import XmlSaveOptions
 from com.aspose.cells import XpsSaveOptions
 
 from com.aspose.cells import CellsHelper
